@@ -10,10 +10,11 @@ use Carp ();
 use File::Spec;
 use Capture::Tiny qw(capture);
 use CPAN::Testers::Common::Client::PrereqCheck;
+use CPAN::Testers::Common::Client::History;
 
 use constant MAX_OUTPUT_LENGTH => 1_000_000;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 
 #==================================
@@ -121,6 +122,37 @@ sub command {
 #  PUBLIC METHODS
 #====================================
 
+sub is_duplicate {
+    my ($self) = @_;
+
+    my $grade     = $self->grade;
+    my $dist_name = $self->distname;
+    return 0 unless $grade && $dist_name;
+
+    #FIXME: CPAN::Reporter allows for 3 phases: 'PL', 'make' or 'test'.
+    # Until this is properly ported, we'll only use the 'test' phase.
+    return CPAN::Testers::Common::Client::History::is_duplicate({
+        phase     => 'test',
+        grade     => $grade,
+        dist_name => $dist_name,
+    });
+}
+
+sub record_history {
+    my ($self) = @_;
+
+    my $grade     = $self->grade;
+    my $dist_name = $self->distname;
+    return unless $grade && $dist_name;
+
+    #FIXME: CPAN::Reporter allows for 3 phases: 'PL', 'make' or 'test'.
+    # Until this is properly ported, we'll only use the 'test' phase.
+    return CPAN::Testers::Common::Client::History::record_history({
+        phase     => 'test',
+        grade     => $grade,
+        dist_name => $dist_name,
+    });
+}
 
 sub populate {
     my $self = shift;
@@ -183,7 +215,7 @@ sub _populate_testenvironment {
 
 sub _populate_prereqs {
     my $self = shift;
-   
+
     # TODO: update Fact::Prereqs to use the new meta::spec for prereqs 
     # TODO: add the 'test' prereqs?
     return $self->{_meta}{prereqs}
@@ -495,15 +527,14 @@ sub _temp_filename {
 # CPAN::Distribution::unsat_prereq()
 #
 #--------------------------------------------------------------------------#
- 
 my $version_finder = $INC{'CPAN/Testers/Common/Client/PrereqCheck.pm'};
- 
+
 sub _version_finder {
     my %prereqs = @_;
- 
+
     my $perl = Probe::Perl->find_perl_interpreter();
     my @prereq_results;
- 
+
     my $prereq_input = _temp_filename( 'CTCC-' );
     open my $fh, '>', $prereq_input
         or die "Could not create temporary '$prereq_input' for prereq analysis: $!";
@@ -787,6 +818,16 @@ This method B<will> call C<populate()> if populate hasn't been called yet.
 Returns the already populated metabase data structure. Note that this will B<NOT> call C<populate()>
 so you will get undef or cached data unless you call C<populate()> yourself.
 
+=head3 is_duplicate
+
+Returns true if this report was already sent by the current user in the past,
+and false otherwise.
+
+=head3 record_history
+
+Records report into the history file (so C<is_duplicate()> returns true for
+it in the future.
+
 =head1 CONFIGURATION AND ENVIRONMENT
 
 =head2 AUTOMATED_TESTING
